==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/cs.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Značky",
    "Update" : "Aktualizovat",
    "Create" : "Vytvořit",
    "Select tag…" : "Zvolit značku…",
    "Tagged files" : "Otagované soubory",
    "Select tags to filter by" : "Vybrat tagy pro filtr",
    "No tags found" : "Nebyly nalezeny žádné tagy",
    "Please select tags to filter by" : "Vyberte prosím tagy pro filtrování",
    "No files found for the selected tags" : "Nebyly nalezeny žádné soubory s vybranými tagy",
    "Added system tag %1$s" : "Přidán systémový tag %1$s",
    "Added system tag {systemtag}" : "Přidán systémový tag {systemtag}",
    "%1$s added system tag %2$s" : "%1$s přidal(a) systémový tag %2$s",
    "{actor} added system tag {systemtag}" : "{actor} přidal(a) systémový tag {systemtag}",
    "Removed system tag %1$s" : "Odstraněn systémový tag %1$s",
    "Removed system tag {systemtag}" : "Odstraněn systémový tag {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s odstranil(a) systémový tag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstranil(a) systémový tag {systemtag}",
    "You created system tag %1$s" : "Vytvořil(a) jste systémový tag %1$s",
    "You created system tag {systemtag}" : "Vytvořil(a) jste systémový tag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvořil systémový tag %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvořil(a) systémový tag {systemtag}",
    "You deleted system tag %1$s" : "Odstranil(a) jste systémový tag %1$s",
    "You deleted system tag {systemtag}" : "Odstranil(a) jste systémový tag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s smazal systémový tag %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstranil(a) systémový tag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizoval(a) jste systémový tag %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizoval(a) jste systémový tag {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval systémový tag %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový tag {oldsystemtag} na { newsystemtag}",
    "You added system tag %2$s to %1$s" : "Přidal(a) jste systémový tag %2$s k %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} jste přidal(a) systémový tag {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s přidal systémový štítek %3$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} přidal(a) systémový tag {systemtag} k {file}",
    "You removed system tag %2$s from %1$s" : "Z %2$s jste odstranil(a) systémový tag %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} jste odstranil(a) systémový tag {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstranil systémový štítek %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstranil(a) systémotý tag {systemtag} z {file}",
    "%s (restricted)" : "%s (omezeno)",
    "%s (invisible)" : "%s (neviditelný)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové tagy</strong> souboru byly upraveny",
    "Collaborative tags" : "Značky pro spolupráci",
    "Name" : "Název",
    "Delete" : "Smazat",
    "Public" : "Veřejné",
    "Restricted" : "Omezené",
    "Invisible" : "Neviditelné",
    "Reset" : "Obnovit",
    "No files in here" : "Žádné soubory",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Size" : "Velikost",
    "Modified" : "Upraveno"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/cs.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Značky",
    "Update" : "Aktualizovat",
    "Create" : "Vytvořit",
    "Select tag…" : "Zvolit značku…",
    "Tagged files" : "Otagované soubory",
    "Select tags to filter by" : "Vybrat tagy pro filtr",
    "No tags found" : "Nebyly nalezeny žádné tagy",
    "Please select tags to filter by" : "Vyberte prosím tagy pro filtrování",
    "No files found for the selected tags" : "Nebyly nalezeny žádné soubory s vybranými tagy",
    "Added system tag %1$s" : "Přidán systémový tag %1$s",
    "Added system tag {systemtag}" : "Přidán systémový tag {systemtag}",
    "%1$s added system tag %2$s" : "%1$s přidal(a) systémový tag %2$s",
    "{actor} added system tag {systemtag}" : "{actor} přidal(a) systémový tag {systemtag}",
    "Removed system tag %1$s" : "Odstraněn systémový tag %1$s",
    "Removed system tag {systemtag}" : "Odstraněn systémový tag {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s odstranil(a) systémový tag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstranil(a) systémový tag {systemtag}",
    "You created system tag %1$s" : "Vytvořil(a) jste systémový tag %1$s",
    "You created system tag {systemtag}" : "Vytvořil(a) jste systémový tag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvořil systémový tag %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvořil(a) systémový tag {systemtag}",
    "You deleted system tag %1$s" : "Odstranil(a) jste systémový tag %1$s",
    "You deleted system tag {systemtag}" : "Odstranil(a) jste systémový tag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s smazal systémový tag %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstranil(a) systémový tag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizoval(a) jste systémový tag %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizoval(a) jste systémový tag {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval systémový tag %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový tag {oldsystemtag} na { newsystemtag}",
    "You added system tag %2$s to %1$s" : "Přidal(a) jste systémový tag %2$s k %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} jste přidal(a) systémový tag {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s přidal systémový štítek %3$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} přidal(a) systémový tag {systemtag} k {file}",
    "You removed system tag %2$s from %1$s" : "Z %2$s jste odstranil(a) systémový tag %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} jste odstranil(a) systémový tag {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstranil systémový štítek %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstranil(a) systémotý tag {systemtag} z {file}",
    "%s (restricted)" : "%s (omezeno)",
    "%s (invisible)" : "%s (neviditelný)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové tagy</strong> souboru byly upraveny",
    "Collaborative tags" : "Značky pro spolupráci",
    "Create and edit collaborative tags. These tags affect all users." : "Vytvářejte a upravujte značky pro spolupráci. Tyto značky ovlivní všechny uživatele.",
    "Select tag …" : "Vyberte značku …",
    "Name" : "Název",
    "Delete" : "Smazat",
    "Public" : "Veřejné",
    "Restricted" : "Omezené",
    "Invisible" : "Neviditelné",
    "Reset" : "Obnovit",
    "No files in here" : "Žádné soubory",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Size" : "Velikost",
    "Modified" : "Upraveno"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
